ParseError

Enum ParseError 

pub enum ParseError {
    EndOfStream,
    InvalidMagicNumber(u32),
    InvalidType {
        expected: &'static str,
        found: Code,
    },
    InvalidIdResult(IdRef),
    ExpectedContextResultType,
    InvalidIntLiteralWidth(u32),
    InvalidFloatLiteralWidth(u32),
    IdOutOfBounds {
        bound: u32,
        id: IdResult,
    },
    UnknownVariant {
        kind: &'static str,
        value: u32,
    },
    InvalidPairWordCount(u32),
}
Indicates that the SPIR-V code passed to a module is invalid.

Variants



EndOfStream

Indicates that the end of the stream was reached prematurely.



InvalidMagicNumber(u32)

Indicates a wrong magic number for the module.



InvalidType

Indicates an invalid type.

Fields

expected: &'static str

The expected type.

found: Code

The found Code.



InvalidIdResult(IdRef)

Indicates an invalid result id.



ExpectedContextResultType

Indicates that a context result type was expected, but None was found.



InvalidIntLiteralWidth(u32)

Indicates that an invalid integer literal width was found.



InvalidFloatLiteralWidth(u32)

Indicates that an invalid floating point literal width was found.



IdOutOfBounds

Indicates that an id in SPIR-V was out of the set bounds.

Fields

bound: u32

The set bound.

id: IdResult

The id.



UnknownVariant

Indicates that an unknown variant was found.

Fields

kind: &'static str

The enum type.

value: u32

The found value.



InvalidPairWordCount(u32)

Indicates that an invalid pair word count was found (not a multiple of 2).