pub enum ReflectError {
FromBytesWithNulError(FromBytesWithNulError),
Parse(ParseError),
NoEntryPointSet,
UnknownEntryPoint,
InvalidTypeId(Id),
InvalidConstantId(Id),
NonIntegerLiteral(Literal),
ExpectedConstantLiteral {
found: String,
},
ExpectedScalarType {
found: Code,
},
ExpectedVectorType {
found: Code,
},
MissingRequiredDecoration(&'static str),
InvalidRuntimeArray,
}Expand description
The main error type for when reflection fails.
Variants
FromBytesWithNulError(FromBytesWithNulError)
A CStr error.
Parse(ParseError)
A parsing error.
NoEntryPointSet
An error indicating no entry point is set.
UnknownEntryPoint
An error indicating that the specified entry point was not found.
InvalidTypeId(Id)
An error indicating that a type with Id was not found.
InvalidConstantId(Id)
An error indicating that a constant with Id was not found.
NonIntegerLiteral(Literal)
An error indicating that an integer literal was expected, but a non-integer literal was found.
ExpectedConstantLiteral
An error indicating that a constant with a literal was expected, but another
type of constant was found.
ExpectedScalarType
An error indicating that a scalar type instruction was expected, but another instruction was found.
ExpectedVectorType
An error indicating that a vector type instruction was expected, but another instruction was found.
MissingRequiredDecoration(&'static str)
An error indicating that a required decoration was expected but not found.
InvalidRuntimeArray
An error indicating that an invalid placement of a runtime array.