pub enum TypeSizeHint {
Static(usize),
RuntimeArray(RuntimeArrayHole),
Matrix(MatrixStrideHole),
UnknownArrayStride(UnknownArrayStrideHole),
Struct(StructHole),
}Expand description
A hint of the size of a Type.
It can be a statically known size, or it can have a hole which can be resolved.
Variants
Static(usize)
A statically known size.
RuntimeArray(RuntimeArrayHole)
A runtime array hole.
Matrix(MatrixStrideHole)
A matrix stride hole.
UnknownArrayStride(UnknownArrayStrideHole)
An unknown array stride hole.
Struct(StructHole)
A hole caused by a runtime array at the end of a struct.
Implementations