pub struct Decorate<'a> {
pub target: Id,
pub member: Option<u32>,
pub decoration: Decoration<'a>,
}Expand description
A decoration added to an instruction, or a member of a struct.
Fields
target: IdThe target Id of the decoration.
member: Option<u32>The member index within target, if this decorates a member of a struct.
decoration: Decoration<'a>The Decoration assigned to the target.