pub struct Resource<'a> {
pub type_id: Id,
pub base_type_id: Id,
pub variable_id: Id,
pub name: Option<CompilerStr<'a>>,
pub count: ResourceCount,
pub offset: Option<u32>,
}Expand description
Represents a shader resource.
Fields
type_id: IdThe outer type of the resource.
base_type_id: IdThe inner type of the resource.
variable_id: IdThe variable id of the resource.
name: Option<CompilerStr<'a>>The variable name string of the resource.
count: ResourceCountThe number of base type values in an array.
offset: Option<u32>Offset of the first member in a struct used for push constants.