pub struct RuntimeArrayHole { /* private fields */ }Expand description
A hole created from the declaration of a runtime array.
Can be resolved by giving the number of elements in the array.
Implementations