pub struct StructHole { /* private fields */ }Expand description
A hole created from a struct, which has a runtime array as the last member.
Can be resolved by giving the number of elements in the runtime array.
Implementations