pub struct UnknownArrayStrideHole { /* private fields */ }Expand description
A hole created from the declaration of an array without the array stride decoration.
Can be resolved, by resolving the element type hint.
Implementations