InstructionStream

Struct InstructionStream 

pub struct InstructionStream<'a> { /* private fields */ }
Represents a single SPIR-V instruction stream.

Implementations

Source

impl<'a> InstructionStream<'a>

pub fn code(&self) -> Code

Returns the instruction’s Code.

pub fn is_eos(&self) -> bool

Returns whether the end of the stream has been reached.

pub fn reset(&mut self)

Resets the stream’s position to one.

pub fn advance(&mut self, count: u32) -> ParseResult<()>

Advances the streams position without reading.

pub fn read(&mut self) -> ParseResult<u32>

Reads a word from the stream.

pub fn read_words(&mut self, count: Option<u32>) -> ParseResult<&'a [u32]>

Reads multiple words from the stream.

Pass None for count to read until the end of the stream.

pub fn read_string(&mut self) -> ParseResult<CompilerStr<'a>>

Reads a string.