pub enum ParseError {
EndOfStream,
InvalidMagicNumber(u32),
InvalidType {
expected: &'static str,
found: Code,
},
InvalidIdResult(IdRef),
ExpectedContextResultType,
InvalidIntLiteralWidth(u32),
InvalidFloatLiteralWidth(u32),
IdOutOfBounds {
bound: u32,
id: IdResult,
},
UnknownVariant {
kind: &'static str,
value: u32,
},
InvalidPairWordCount(u32),
}Expand description
Indicates that the SPIR-V code passed to a module is invalid.
Variants
EndOfStream
Indicates that the end of the stream was reached prematurely.
InvalidMagicNumber(u32)
Indicates a wrong magic number for the module.
InvalidType
Indicates an invalid type.
InvalidIdResult(IdRef)
Indicates an invalid result id.
ExpectedContextResultType
InvalidIntLiteralWidth(u32)
Indicates that an invalid integer literal width was found.
InvalidFloatLiteralWidth(u32)
Indicates that an invalid floating point literal width was found.
IdOutOfBounds
Indicates that an id in SPIR-V was out of the set bounds.
UnknownVariant
Indicates that an unknown variant was found.
InvalidPairWordCount(u32)
Indicates that an invalid pair word count was found (not a multiple of 2).