Module

Struct Module 

pub struct Module<'a> { /* private fields */ }
Represents a SPIR-V module.

Implementations

Source

impl<'a> Module<'a>

pub fn new(spirv: &'a [u32]) -> ParseResult<Self>

Creates a new module from SPIR-V words.

pub fn version(&self) -> u32

The SPIR-V version of the module.

pub fn parse_next(&mut self) -> ParseResult<bool>

Tries to parse the next instruction.

pub fn parse_full(&mut self) -> ParseResult<()>

Tries to parse until the end of the inner Stream.

pub fn all_instructions(&self) -> impl Iterator<Item = InstructionStream<'a>>

Returns an iterator over all instruction streams.

pub fn remaining_instructions( &self, ) -> impl Iterator<Item = InstructionStream<'a>>

Returns an iterator over all remaining unparsed instruction streams.

pub fn results(&self) -> impl Iterator<Item = (IdRef, InstructionStream<'a>)>

Returns an iterator over all cached instruction streams with a result.

pub fn get_result(&self, id: IdRef) -> Option<InstructionStream<'a>>

Gets a result with id, returning None if the result is not present.